use nostr::{key::FromPkStr, secp256k1::XOnlyPublicKey};

#[derive(Clone, Debug)]
pub struct Config {
    admin_pubkey: XOnlyPublicKey,
}

impl Default for Config {
    fn default() -> Self {
        panic!("Use Config::new(env_admin_pk)")
    }
}

impl Config {
    pub fn new() -> Self {
        if let Ok(env_admin_pk) = std::env::var("ADMIN_PUBKEY") {
            match nostr::Keys::from_pk_str(&env_admin_pk) {
                Ok(admin_keys) => {
                    return Self {
                        admin_pubkey: admin_keys.public_key(),
                    };
                }
                Err(e) => {
                    panic!("Unable to parse ADMIN_PUBKEY: {}", e);
                }
            }
        }

        panic!("Environment variable ADMIN_PUBKEY not defined");
    }

    pub fn get_admin_pubkey(&self) -> &XOnlyPublicKey {
        &self.admin_pubkey
    }

    pub fn get_relay_config_json(&self) -> serde_json::Value {
        serde_json::json!({
            "contact": "klink@zhitno.st",
            "name": "zhitno.st",
            "description": "Very *special* nostr relay",
            "supported_nips": [ 1, 9, 11, 12, 15, 16, 20, 22, 28, 33 ],
            "software": "git+https://git.zhitno.st/Klink/sneedstr.git",
            "version": "0.1.0"
        })
    }
}
